@@ -167,7 +167,7 @@ bool ConfigHandler::checkSaveandTestCommon(bool isSaveCheck)
                     || (isSaveCheck && output->sdrGamutWideness() != config->sdrGamutWideness())
                     || output->colorProfileSource() != config->colorProfileSource()
                     || (isSaveCheck && output->brightness() != config->brightness())
-                    || (isSaveCheck && output->colorPowerPreference() != config->colorPowerPreference())) {
+                    || output->colorPowerPreference() != config->colorPowerPreference()) {
                         return true;
                     }
             }
