@@ -119,6 +119,10 @@ QVariant OutputModel::data(const QModelIndex &index, int role) const
         return output->sdrGamutWideness();
     case ColorProfileSource:
         return static_cast<uint32_t>(output->colorProfileSource());
+    case BrightnessRole:
+        return output->brightness();
+    case ColorPowerPreference:
+        return static_cast<uint32_t>(output->colorPowerPreference());
     }
     return QVariant();
 }
@@ -281,6 +285,14 @@ bool OutputModel::setData(const QModelIndex &index, const QVariant &value, int r
         output.ptr->setColorProfileSource(static_cast<KScreen::Output::ColorProfileSource>(value.toUInt()));
         Q_EMIT dataChanged(index, index, {role});
         return true;
+    case BrightnessRole:
+        output.ptr->setBrightness(value.toDouble());
+        Q_EMIT dataChanged(index, index, {role});
+        return true;
+    case ColorPowerPreference:
+        output.ptr->setColorPowerPreference(static_cast<KScreen::Output::ColorPowerTradeoff>(value.toUInt()));
+        Q_EMIT dataChanged(index, index, {role});
+        return true;
     }
     return false;
 }
@@ -316,6 +328,8 @@ QHash<int, QByteArray> OutputModel::roleNames() const
     roles[MaxBrightnessRole] = "peakBrightness";
     roles[SdrGamutWideness] = "sdrGamutWideness";
     roles[ColorProfileSource] = "colorProfileSource";
+    roles[BrightnessRole] = "brightness";
+    roles[ColorPowerPreference] = "colorPowerPreference";
     return roles;
 }
 
