@@ -3,8 +3,7 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef KDED_CONFIG_H
-#define KDED_CONFIG_H
+#pragma once
 
 #include <kscreen/config.h>
 
@@ -36,10 +35,6 @@ public:
     }
 
     void activateControlWatching();
-    bool autoRotationRequested() const;
-    void setDeviceOrientation(QOrientationReading::Orientation orientation);
-    bool getAutoRotate() const;
-    void setAutoRotate(bool value);
     void log();
 
     void setValidityFlags(KScreen::Config::ValidityFlags flags)
@@ -67,7 +62,4 @@ private:
 
     static QString s_configsDirName;
     static QString s_fixedConfigFileName;
-
 };
-
-#endif
